==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="vi" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Tạo bảng tính</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Tạo một bảng tính mới</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Căn dưới</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên dưới của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Căn giữa</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh chính giữa của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Căn trái</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên trái của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Căn phải</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên phải của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Căn trên</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên trên của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Căn giữa theo chiều dọc</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Xuất bảng tính</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Xuất bảng tính thành tệp CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Nhập bảng tính</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Nhập tệp CSV thành bảng tính</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sát nhập các ô</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Sát nhập các ô được chọn trong cùng một bảng tính</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Đặt biệt hiệu</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Đặt biệt hiệu cho ô được chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Chia ô</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Tách các ô được sát nhập trước đó trong bảng tính</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Chữ in đậm</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Đặt kiểu chữ in đậm cho các ô được chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Chữ in nghiêng</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Đặt kiểu chữ in nghiêng cho các ô được chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Chữ gạch chân</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Thuộc tính ô</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Màu sắc</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Văn bản</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Hình nền</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Căn chỉnh</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Trái</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Trung tâm</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Phải</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Đỉnh</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Đáy</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Kiểu</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>In đậm</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>In nghiêng</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Gạch chân</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Đơn vị hiển thị</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Chuỗi đơn vị</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>B&amp;iệt hiệu</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Biệt hiệu cho ô này</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tất cả (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Nhập tập tin</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Xuất tập tin</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Nội dung trong ô</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Hiển thị bảng tính</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Đặt màu nền trước cho (các) ô</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Đặt màu nền trước cho (các) ô trong bảng tính</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Đặt màu nền sau cho (các) ô</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Đặt màu nền sau cho (các) ô trong bảng tính</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Màu đen</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Trắng</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Đỏ</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Đỏ sẫm</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Xanh lá cây</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Xanh lục đậm</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Xanh da trời</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Xanh dương đậm</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Màu xanh lá mạ</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Xanh lơ đậm</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Đỏ tươi</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Màu đỏ sẫm</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Vàng</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Vàng đậm</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Xám</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Xám đậm</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Xám nhạt</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Tùy chọn</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Hình thức</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Nội dung</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Không có tên</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Chèn hàng</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Xóa hàng</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Chèn Cột</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Xóa cột</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Thuộc tính...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Tạo bảng tính</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Tạo một bảng tính mới</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Căn dưới</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên dưới của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Căn giữa</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh chính giữa của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Căn trái</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên trái của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Căn phải</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên phải của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Căn trên</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh bên trên của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Căn giữa theo chiều dọc</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Nội dung căn chỉnh chính giữa của các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Xuất bảng tính</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Xuất bảng tính thành tệp CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Nhập bảng tính</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Nhập tệp CSV thành bảng tính</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sát nhập các ô</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Trộn các ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Đặt biệt hiệu</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Đặt biệt hiệu cho ô được chọn</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Chia ô</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Tách rời các ô đã được hòa trộn trước đây</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>In đậm chữ</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Đặt chữ trong các ô thành đậm</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Làm nghiêng chữ</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Đặt chữ trong các ô thành nghiêng</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Gạch chân chữ</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Gạch chân chữ trong ô đã chọn</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Màu tự chọn</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Sát nhập các ô</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Chia ô</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation>Ô canh lề trái</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation>Ô trung tâm</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation>Ô canh lề phải</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation>Ô canh lề phía trên</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation>Ô canh lề phía dưới</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>Ô trung tâm chiều dọc</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation>Tô đậm văn bản</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>Chuyển sang chữ in nghiêng</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation>Gạch chân chữ</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation>Tạo bảng tính</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>Đặt thuộc tính ô</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>Hiệu chỉnh ô</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Chèn hàng</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Xóa hàng</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Chèn Cột</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation>Tẩy ô</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>Đặt màu nổi</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>Đặt màu chìm</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Thuộc tính ô</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Màu sắc</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Văn bản</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Hình nền</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Căn chỉnh</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Nằm ngang</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Trái</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Trung tâm</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Phải</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Nằm dọc</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Đỉnh</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Đáy</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Kiểu</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>In đậm</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>In nghiêng</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Gạch chân</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Đơn vị hiển thị</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Chuỗi đơn vị</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>B&amp;iệt hiệu</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Biệt hiệu cho ô này</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tất cả (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Nhập tập tin</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Xuất tập tin</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Hiển thị bảng tính</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Đặt màu nền trước cho (các) ô</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Đặt màu nền trước cho (các) ô trong bảng tính</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Đặt màu nền sau cho (các) ô</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Đặt màu nền sau cho (các) ô trong bảng tính</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Bảng tính không hỗ trợ khoảng chọn khi dán. Xin chỉ chọn một ô.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Copy &amp; dán thất bại</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Tên đại diện chứa các ký tự không hợp lệ!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Liên hệ tới ô bằng tên đại diện, ví dụ: Bảng_tính.tên_đại_diện thay vì Bảng_tính.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Màu đen</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Trắng</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Đỏ</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Đỏ sẫm</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Xanh lá cây</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Xanh lục đậm</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Xanh da trời</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Xanh dương đậm</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Màu xanh lá mạ</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Xanh lơ đậm</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Đỏ tươi</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Màu đỏ sẫm</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Vàng</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Vàng đậm</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Xám</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Xám đậm</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Xám nhạt</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Màu tự chọn</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Hình thức</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Nội dung:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Tên đại diện:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Liên hệ tới ô bằng tên đại diện, ví dụ: Bảng_tính.tên_đại_diện thay vì Bảng_tính.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Không có tên</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Chèn hàng</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Xóa hàng</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Chèn Cột</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Xóa cột</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Thuộc tính...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Bảng tính</translation>
    </message>
  </context>
</TS>
